@@ -21,10 +21,12 @@
 #define D_PTR EwsItemPrivate *d = reinterpret_cast<EwsItemPrivate *>(this->d.data());
 #define D_CPTR const EwsItemPrivate *d = reinterpret_cast<const EwsItemPrivate *>(this->d.data());
 
+using namespace Qt::StringLiterals;
+
 class EwsItemPrivate : public EwsItemBasePrivate
 {
 public:
-    typedef EwsXml<EwsItemFields> Reader;
+    using Reader = EwsXml<EwsItemFields>;
 
     EwsItemPrivate();
     EwsItemPrivate(const EwsItemBasePrivate &other);
@@ -55,60 +57,59 @@ public:
 
 static const QList<EwsItemPrivate::Reader::Item> ewsItemItems = {
     // Item fields
-    {EwsItemFieldMimeContent, QStringLiteral("MimeContent"), &ewsXmlBase64Reader, &ewsXmlBase64Writer},
-    {EwsItemFieldItemId, QStringLiteral("ItemId"), &ewsXmlIdReader, &ewsXmlIdWriter},
-    {EwsItemFieldParentFolderId, QStringLiteral("ParentFolderId"), &ewsXmlIdReader, &ewsXmlIdWriter},
-    {EwsItemFieldItemClass, QStringLiteral("ItemClass"), &ewsXmlTextReader, &ewsXmlTextWriter},
-    {EwsItemFieldSubject, QStringLiteral("Subject"), &ewsXmlTextReader, &ewsXmlTextWriter},
-    {EwsItemFieldSensitivity, QStringLiteral("Sensitivity"), &ewsXmlSensitivityReader},
-    {EwsItemFieldBody, QStringLiteral("Body"), &EwsItemPrivate::bodyReader},
-    {EwsItemFieldAttachments, QStringLiteral("Attachments"), &EwsItemPrivate::attachmentsReader},
-    {EwsItemFieldDateTimeReceived, QStringLiteral("DateTimeReceived"), &ewsXmlDateTimeReader},
-    {EwsItemFieldSize, QStringLiteral("Size"), &ewsXmlUIntReader},
-    {EwsItemFieldCategories, QStringLiteral("Categories"), &EwsItemPrivate::categoriesReader, &EwsItemPrivate::categoriesWriter},
-    {EwsItemFieldImportance, QStringLiteral("Importance"), &ewsXmlImportanceReader},
-    {EwsItemFieldInReplyTo, QStringLiteral("InReplyTo"), &ewsXmlTextReader},
-    {EwsItemFieldIsDraft, QStringLiteral("IsDraft"), &ewsXmlBoolReader, &ewsXmlBoolWriter},
-    {EwsItemFieldIsFromMe, QStringLiteral("IsFromMe"), &ewsXmlBoolReader},
-    {EwsItemFieldInternetMessageHeaders, QStringLiteral("InternetMessageHeaders"), &EwsItemPrivate::messageHeadersReader},
-    {EwsItemFieldExtendedProperties,
-     QStringLiteral("ExtendedProperty"),
-     &EwsItemBasePrivate::extendedPropertyReader,
-     &EwsItemBasePrivate::extendedPropertyWriter},
-    {EwsItemFieldHasAttachments, QStringLiteral("HasAttachments"), &ewsXmlBoolReader},
+    {EwsItemFieldMimeContent, "MimeContent"_L1, &ewsXmlBase64Reader, &ewsXmlBase64Writer},
+    {EwsItemFieldItemId, "ItemId"_L1, &ewsXmlIdReader, &ewsXmlIdWriter},
+    {EwsItemFieldParentFolderId, "ParentFolderId"_L1, &ewsXmlIdReader, &ewsXmlIdWriter},
+    {EwsItemFieldItemClass, "ItemClass"_L1, &ewsXmlTextReader, &ewsXmlTextWriter},
+    {EwsItemFieldSubject, "Subject"_L1, &ewsXmlTextReader, &ewsXmlTextWriter},
+    {EwsItemFieldSensitivity, "Sensitivity"_L1, &ewsXmlSensitivityReader},
+    {EwsItemFieldBody, "Body"_L1, &EwsItemPrivate::bodyReader},
+    {EwsItemFieldAttachments, "Attachments"_L1, &EwsItemPrivate::attachmentsReader},
+    {EwsItemFieldDateTimeReceived, "DateTimeReceived"_L1, &ewsXmlDateTimeReader},
+    {EwsItemFieldDateTimeSent, "DateTimeSent"_L1, &ewsXmlDateTimeReader},
+    {EwsItemFieldDateTimeCreated, "DateTimeCreated"_L1, &ewsXmlDateTimeReader},
+    {EwsItemFieldSize, "Size"_L1, &ewsXmlUIntReader},
+    {EwsItemFieldCategories, "Categories"_L1, &EwsItemPrivate::categoriesReader, &EwsItemPrivate::categoriesWriter},
+    {EwsItemFieldImportance, "Importance"_L1, &ewsXmlImportanceReader},
+    {EwsItemFieldInReplyTo, "InReplyTo"_L1, &ewsXmlTextReader},
+    {EwsItemFieldIsDraft, "IsDraft"_L1, &ewsXmlBoolReader, &ewsXmlBoolWriter},
+    {EwsItemFieldIsFromMe, "IsFromMe"_L1, &ewsXmlBoolReader},
+    {EwsItemFieldInternetMessageHeaders, "InternetMessageHeaders"_L1, &EwsItemPrivate::messageHeadersReader},
+    {EwsItemFieldExtendedProperties, "ExtendedProperty"_L1, &EwsItemBasePrivate::extendedPropertyReader, &EwsItemBasePrivate::extendedPropertyWriter},
+    {EwsItemFieldHasAttachments, "HasAttachments"_L1, &ewsXmlBoolReader},
     // Message fields
-    {EwsItemFieldToRecipients, QStringLiteral("ToRecipients"), &EwsItemPrivate::recipientsReader},
-    {EwsItemFieldCcRecipients, QStringLiteral("CcRecipients"), &EwsItemPrivate::recipientsReader},
-    {EwsItemFieldBccRecipients, QStringLiteral("BccRecipients"), &EwsItemPrivate::recipientsReader},
-    {EwsItemFieldFrom, QStringLiteral("From"), &EwsItemPrivate::mailboxReader},
-    {EwsItemFieldInternetMessageId, QStringLiteral("InternetMessageId"), &ewsXmlTextReader},
-    {EwsItemFieldIsRead, QStringLiteral("IsRead"), &ewsXmlBoolReader, &ewsXmlBoolWriter},
-    {EwsItemFieldReferences, QStringLiteral("References"), &ewsXmlTextReader},
-    {EwsItemFieldReplyTo, QStringLiteral("ReplyTo"), &EwsItemPrivate::mailboxReader},
+    {EwsItemFieldToRecipients, "ToRecipients"_L1, &EwsItemPrivate::recipientsReader},
+    {EwsItemFieldCcRecipients, "CcRecipients"_L1, &EwsItemPrivate::recipientsReader},
+    {EwsItemFieldBccRecipients, "BccRecipients"_L1, &EwsItemPrivate::recipientsReader},
+    {EwsItemFieldFrom, "From"_L1, &EwsItemPrivate::mailboxReader},
+    {EwsItemFieldInternetMessageId, "InternetMessageId"_L1, &ewsXmlTextReader},
+    {EwsItemFieldIsRead, "IsRead"_L1, &ewsXmlBoolReader, &ewsXmlBoolWriter},
+    {EwsItemFieldReferences, "References"_L1, &ewsXmlTextReader},
+    {EwsItemFieldReplyTo, "ReplyTo"_L1, &EwsItemPrivate::mailboxReader},
     // CalendarItem fields
-    {EwsItemFieldCalendarItemType, QStringLiteral("CalendarItemType"), &ewsXmlCalendarItemTypeReader},
-    {EwsItemFieldUID, QStringLiteral("UID"), &ewsXmlTextReader},
-    {EwsItemFieldCulture, QStringLiteral("Culture"), &ewsXmlTextReader},
-    {EwsItemFieldStartTimeZone, QStringLiteral("StartTimeZone"), &EwsItemPrivate::timezoneReader},
-    {EwsItemFieldOrganizer, QStringLiteral("Organizer"), &EwsItemPrivate::mailboxReader},
-    {EwsItemFieldRequiredAttendees, QStringLiteral("RequiredAttendees"), &EwsItemPrivate::attendeesReader},
-    {EwsItemFieldOptionalAttendees, QStringLiteral("OptionalAttendees"), &EwsItemPrivate::attendeesReader},
-    {EwsItemFieldResources, QStringLiteral("Resources"), &EwsItemPrivate::attendeesReader},
-    {EwsItemFieldStart, QStringLiteral("Start"), &ewsXmlDateTimeReader},
-    {EwsItemFieldEnd, QStringLiteral("End"), &ewsXmlDateTimeReader},
-    {EwsItemFieldRecurrenceId, QStringLiteral("RecurrenceId"), &ewsXmlDateTimeReader},
-    {EwsItemFieldIsAllDayEvent, QStringLiteral("IsAllDayEvent"), &ewsXmlBoolReader},
-    {EwsItemFieldLegacyFreeBusyStatus, QStringLiteral("LegacyFreeBusyStatus"), &ewsXmlLegacyFreeBusyStatusReader},
-    {EwsItemFieldMyResponseType, QStringLiteral("MyResponseType"), &ewsXmlResponseTypeReader},
-    {EwsItemFieldAppointmentSequenceNumber, QStringLiteral("AppointmentSequenceNumber"), &ewsXmlUIntReader},
-    {EwsItemFieldRecurrence, QStringLiteral("Recurrence"), &EwsItemPrivate::recurrenceReader},
-    {EwsItemFieldFirstOccurrence, QStringLiteral("FirstOccurrence"), &EwsItemPrivate::occurrenceReader},
-    {EwsItemFieldLastOccurrence, QStringLiteral("LastOccurrence"), &EwsItemPrivate::occurrenceReader},
-    {EwsItemFieldModifiedOccurrences, QStringLiteral("ModifiedOccurrences"), &EwsItemPrivate::occurrencesReader},
-    {EwsItemFieldDeletedOccurrences, QStringLiteral("DeletedOccurrences"), &EwsItemPrivate::occurrencesReader},
-    {EwsItemFieldTimeZone, QStringLiteral("TimeZone"), &ewsXmlTextReader},
-    {EwsItemFieldExchangePersonIdGuid, QStringLiteral("ExchangePersonIdGuid"), &ewsXmlTextReader},
-    {EwsItemFieldDoNotForwardMeeting, QStringLiteral("DoNotForwardMeeting"), &ewsXmlBoolReader},
+    {EwsItemFieldCalendarItemType, "CalendarItemType"_L1, &ewsXmlCalendarItemTypeReader},
+    {EwsItemFieldUID, "UID"_L1, &ewsXmlTextReader},
+    {EwsItemFieldCulture, "Culture"_L1, &ewsXmlTextReader},
+    {EwsItemFieldStartTimeZone, "StartTimeZone"_L1, &EwsItemPrivate::timezoneReader},
+    {EwsItemFieldOrganizer, "Organizer"_L1, &EwsItemPrivate::mailboxReader},
+    {EwsItemFieldRequiredAttendees, "RequiredAttendees"_L1, &EwsItemPrivate::attendeesReader},
+    {EwsItemFieldOptionalAttendees, "OptionalAttendees"_L1, &EwsItemPrivate::attendeesReader},
+    {EwsItemFieldResources, "Resources"_L1, &EwsItemPrivate::attendeesReader},
+    {EwsItemFieldStart, "Start"_L1, &ewsXmlDateTimeReader},
+    {EwsItemFieldEnd, "End"_L1, &ewsXmlDateTimeReader},
+    {EwsItemFieldRecurrenceId, "RecurrenceId"_L1, &ewsXmlDateTimeReader},
+    {EwsItemFieldIsAllDayEvent, "IsAllDayEvent"_L1, &ewsXmlBoolReader},
+    {EwsItemFieldLegacyFreeBusyStatus, "LegacyFreeBusyStatus"_L1, &ewsXmlLegacyFreeBusyStatusReader},
+    {EwsItemFieldMyResponseType, "MyResponseType"_L1, &ewsXmlResponseTypeReader},
+    {EwsItemFieldAppointmentSequenceNumber, "AppointmentSequenceNumber"_L1, &ewsXmlUIntReader},
+    {EwsItemFieldRecurrence, "Recurrence"_L1, &EwsItemPrivate::recurrenceReader},
+    {EwsItemFieldFirstOccurrence, "FirstOccurrence"_L1, &EwsItemPrivate::occurrenceReader},
+    {EwsItemFieldLastOccurrence, "LastOccurrence"_L1, &EwsItemPrivate::occurrenceReader},
+    {EwsItemFieldModifiedOccurrences, "ModifiedOccurrences"_L1, &EwsItemPrivate::occurrencesReader},
+    {EwsItemFieldDeletedOccurrences, "DeletedOccurrences"_L1, &EwsItemPrivate::occurrencesReader},
+    {EwsItemFieldTimeZone, "TimeZone"_L1, &ewsXmlTextReader},
+    {EwsItemFieldExchangePersonIdGuid, "ExchangePersonIdGuid"_L1, &ewsXmlTextReader},
+    {EwsItemFieldDoNotForwardMeeting, "DoNotForwardMeeting"_L1, &ewsXmlBoolReader},
 };
 
 const EwsItemPrivate::Reader EwsItemPrivate::mStaticEwsXml(ewsItemItems);
