@@ -14,7 +14,6 @@
 #include "sessionpool.h"
 #include "sessionuiproxy.h"
 #include "settings.h"
-#include "setupserver.h"
 #include <config-imap.h>
 
 #ifdef WITH_GMAIL_XOAUTH2
@@ -40,6 +39,7 @@ ImapResource::ImapResource(const QString &id)
     m_pool->setClientId(clientId());
 
     settings(); // make sure the D-Bus settings interface is up
+    init();
 }
 
 ImapResource::~ImapResource() = default;
@@ -54,27 +54,4 @@ QByteArray ImapResource::clientId() const
     return QByteArrayLiteral("Kontact IMAP Resource");
 }
 
-QDialog *ImapResource::createConfigureDialog(WId windowId)
-{
-    auto dlg = new SetupServer(this, windowId);
-    dlg->setAttribute(Qt::WA_NativeWindow, true);
-    KWindowSystem::setMainWindow(dlg->windowHandle(), windowId);
-    dlg->setWindowTitle(i18nc("@title:window", "IMAP Account Settings"));
-    dlg->setWindowIcon(QIcon::fromTheme(QStringLiteral("network-server")));
-    connect(dlg, &SetupServer::finished, this, &ImapResource::onConfigurationDone);
-    return dlg;
-}
-
-void ImapResource::onConfigurationDone(int result)
-{
-    auto dlg = qobject_cast<SetupServer *>(sender());
-    if (result) {
-        if (dlg->shouldClearCache()) {
-            clearCache();
-        }
-        settings()->save();
-    }
-    dlg->deleteLater();
-}
-
 #include "moc_imapresource.cpp"
